==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkPNGWriter.java <==
// java wrapper for vtkPNGWriter object
//

package vtk;
import vtk.*;

public class vtkPNGWriter extends vtkImageWriter
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Write_2();
  public void Write()
    { Write_2(); }

  private native void SetCompressionLevel_3(int id0);
  public void SetCompressionLevel(int id0)
    { SetCompressionLevel_3(id0); }

  private native int GetCompressionLevelMinValue_4();
  public int GetCompressionLevelMinValue()
    { return GetCompressionLevelMinValue_4(); }

  private native int GetCompressionLevelMaxValue_5();
  public int GetCompressionLevelMaxValue()
    { return GetCompressionLevelMaxValue_5(); }

  private native int GetCompressionLevel_6();
  public int GetCompressionLevel()
    { return GetCompressionLevel_6(); }

  private native void SetWriteToMemory_7(int id0);
  public void SetWriteToMemory(int id0)
    { SetWriteToMemory_7(id0); }

  private native int GetWriteToMemory_8();
  public int GetWriteToMemory()
    { return GetWriteToMemory_8(); }

  private native void WriteToMemoryOn_9();
  public void WriteToMemoryOn()
    { WriteToMemoryOn_9(); }

  private native void WriteToMemoryOff_10();
  public void WriteToMemoryOff()
    { WriteToMemoryOff_10(); }

  private native void SetResult_11(vtkUnsignedCharArray id0);
  public void SetResult(vtkUnsignedCharArray id0)
    { SetResult_11(id0); }

  private native long GetResult_12();
  public vtkUnsignedCharArray GetResult() {
    long temp = GetResult_12();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  public vtkPNGWriter() { super(); }

  public vtkPNGWriter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkPNGWriter.java <==
// java wrapper for vtkPNGWriter object
//

package vtk;
import vtk.*;

public class vtkPNGWriter extends vtkImageWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Write_2();
  public void Write()
    { Write_2(); }

  private native void SetCompressionLevel_3(int id0);
  public void SetCompressionLevel(int id0)
    { SetCompressionLevel_3(id0); }

  private native int GetCompressionLevelMinValue_4();
  public int GetCompressionLevelMinValue()
    { return GetCompressionLevelMinValue_4(); }

  private native int GetCompressionLevelMaxValue_5();
  public int GetCompressionLevelMaxValue()
    { return GetCompressionLevelMaxValue_5(); }

  private native int GetCompressionLevel_6();
  public int GetCompressionLevel()
    { return GetCompressionLevel_6(); }

  private native void SetWriteToMemory_7(int id0);
  public void SetWriteToMemory(int id0)
    { SetWriteToMemory_7(id0); }

  private native int GetWriteToMemory_8();
  public int GetWriteToMemory()
    { return GetWriteToMemory_8(); }

  private native void WriteToMemoryOn_9();
  public void WriteToMemoryOn()
    { WriteToMemoryOn_9(); }

  private native void WriteToMemoryOff_10();
  public void WriteToMemoryOff()
    { WriteToMemoryOff_10(); }

  private native void SetResult_11(vtkUnsignedCharArray id0);
  public void SetResult(vtkUnsignedCharArray id0)
    { SetResult_11(id0); }

  private native long GetResult_12();
  public vtkUnsignedCharArray GetResult() {
    long temp = GetResult_12();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void AddText_13(String id0,String id1);
  public void AddText(String id0,String id1)
    { AddText_13(id0,id1); }

  public vtkPNGWriter() { super(); }

  public vtkPNGWriter(long id) { super(id); }
  public native long   VTKInit();

}
